@@ -1,6 +1,5 @@
 """Yale Doorman client library."""
 from .client import Client
+from .device import Device
 
-__all__ = [
-    "Client",
-]
+__all__ = ["Client", "Device"]
